@@ -26,15 +26,7 @@ require Exporter;
 @ISA = qw(Exporter AutoLoader);
 @EXPORT = qw();
 
-$VERSION = '0.05';
-
-
-# Preloaded methods go here.
-
-BEGIN {
-  Imager::init_log("Plot.log",1);
-}
-
+$VERSION = '0.06';
 
 
 # Plot generation process:
@@ -66,52 +58,44 @@ sub new {
   my $class = ref($proto) || $proto;
 
   my %opts=(
-	    Width  => 400, # default size if no image is given
-	    Height => 300,
-	    Image    => undef,
+	    Width        => 400, # default size if no image is given
+	    Height       => 300,
+	    Image        => undef,
 	    LeftMargin   => 10,  # This is global 'extra' space, nothing should be painted in it
 	    RightMargin  => 10,
 	    TopMargin    => 10,
 	    BottomMargin => 10,
 	    TitleMargin  => 15,
-	    XLabelMargin => 10,
-	    YLabelMargin => 10,
+	    XlabelMargin => 10,
+	    YlabelMargin => 10,
 	    Title        => "",
 	    GlobalFont   => undef,
-
 	    Xlabel       => "",
 	    Ylabel       => "",
-
+	    
 	    @_);
 
   my $fname = $opts{GlobalFont};
   my $black = Imager::Color->new(0,0,0,0);
 
-  $opts{XlabelFont} = Imager::Font->new(file => $fname, size=>12,color=>$black)
-    if !$opts{XlabelFont};
-	
-  $opts{YlabelFont} = Imager::Font->new(file => $fname, size=>12,color=>$black)
-    if !$opts{YlabelFont};
+  if(!$opts{XlabelFont}) {
+      $opts{XlabelFont} = (ref($fname)) ? $fname : Imager::Font->new(file => $fname, size=>12,color=>$black);
+  }
+	  
+  if(!$opts{YlabelFont}) {
+      $opts{YlabelFont} = (ref($fname)) ? $fname : Imager::Font->new(file => $fname, size=>12,color=>$black);
+  }
+
+  if(!$opts{TitleFont}) {
+      $opts{TitleFont}  = (ref($fname)) ? $fname : Imager::Font->new(file => $fname, size=>16,color=>$black);
+  }
 
-  $opts{TitleFont}  = Imager::Font->new(file => $fname, size=>16,color=>$black)
-    if !$opts{TitleFont};
-	
   my $self  = \%opts;
   bless ($self, $class);
   return $self;
 }
 
 
-# sub axis_new {
-#   my $self = shift;
-#   my %opts = @_;
-#   my $n = $opts{subplot}->[0] || 1;
-#   my $m = $opts{subplot}->[1] || 1;
-#   my $ax = Imager::Plot::Axis->new();
-#   if ($ax) { $self->{SubPlot}->[$n-1]->[$m-1] = $ax; return $ax; }
-#   return ();
-# }
-
 
 sub Set {
   my $self = shift;
@@ -121,7 +105,6 @@ sub Set {
   }
 }
 
-
 sub SetDimensions {
   my $self = shift;
   if ($self->{Image}) {
@@ -130,10 +113,10 @@ sub SetDimensions {
   }
 
   if ($self->{XAxis} and !$self->{Width}) {
-    $self->{Width}  = $self->{XAxis} + $self->{LeftMargin} + $self->{RightMargin} + $self->{YLabelMargin};
+    $self->{Width}  = $self->{XAxis} + $self->{LeftMargin} + $self->{RightMargin} + $self->{YlabelMargin};
   }
   if ($self->{Width} and !$self->{XAxis}) {
-    $self->{XAxis} = $self->{Width} - ( $self->{LeftMargin} + $self->{RightMargin} + $self->{YLabelMargin} );
+    $self->{XAxis} = $self->{Width} - ( $self->{LeftMargin} + $self->{RightMargin} + $self->{YlabelMargin} );
   }
 
   if ($self->{YAxis} and !$self->{Height}) {
@@ -145,6 +128,7 @@ sub SetDimensions {
 
 }
 
+
 sub GetAxis {
   my $self = shift;
   $self->SetDimensions();
@@ -153,7 +137,6 @@ sub GetAxis {
 					    Height     => $self->{YAxis},
 					    GlobalFont => $self->{GlobalFont});
   }
-
   return $self->{AXIS};
 }
 
@@ -161,12 +144,7 @@ sub GetAxis {
 
 sub AddDataSet {
   my $self = shift;
-  my $dataset = Imager::Plot::DataSet->new(@_);
-  if ($dataset) {
-    $self->GetAxis->AddDataSet($dataset);
-    return $dataset;
-  }
-  return;
+  return $self->GetAxis->AddDataSet(@_);
 }
 
 
@@ -175,32 +153,39 @@ sub Render {
   my %opts = @_;
 
   my $Axis = $self->GetAxis();
-  $Axis->Render(Image=>$opts{Image},
-		Xoff => $opts{Xoff}+$self->{LeftMargin},
-		Yoff => $opts{Yoff}-$self->{BottomMargin});
+  my $Xoff = $opts{Xoff} + $self->{LeftMargin},
+  my $Yoff = $opts{Yoff} - $self->{BottomMargin},
+  delete $opts{Xoff};
+  delete $opts{Yoff};
+
+  $Axis->Render(
+		Xoff => $Xoff,
+		Yoff => $Yoff,
+		%opts
+		);
 
 
-  $self->RenderLabels(Image  => $opts{Image},
-		      Xoff   => $opts{Xoff}+$self->{LeftMargin},
-		      Yoff   => $opts{Yoff}-$self->{BottomMargin});
+  $self->RenderLabels(
+		      Xoff   => $Xoff,
+		      Yoff   => $Yoff,
+		      %opts
+		      );
 
 
 }
 
-
-
 sub RenderLabels {
 
   my $self = shift;
-  my %opts  = @_;
-  my $img    = $opts{Image};
+  my %opts = @_;
+  my $img  = $opts{Image};
 
   my $ymin = $opts{Yoff} - $self->GetAxis()->{Height};
   my $ymax = $opts{Yoff};
   my $xmin = $opts{Xoff};
   my $xmax = $opts{Xoff} + $self->GetAxis()->{Width};
 
-  my $xx = ($xmin+$xmax)/2;
+  my $xx   = ($xmin+$xmax)/2;
 
   my $string = $self->{Xlabel};
   my $font   = $self->{XlabelFont};
@@ -215,7 +200,7 @@ sub RenderLabels {
   $img->string(font  => $font,
 	       text  => $string,
 	       x     => $xx-($neg_width+$pos_width)/2,
-	       y     => $ymax+$global_ascent+$self->GetAxis()->{'XtickFont'}->{'size'}+5,
+	       y     => $ymax+$global_ascent+$self->GetAxis()->{'XtickFont'}->{'size'}+$self->{XlabelMargin},
 	       aa    => 1);
 
 
@@ -229,12 +214,19 @@ sub RenderLabels {
    $descent,
    $ascent) = $font->bounding_box(string=>$string);
 
-  $img->string(font  => $font,
-	       text  => $string,
-	       x     => $xmin-10,    # XXX: Fudge factor
-	       y     => $ymin-3,     # more fudge
-	       aa    => 1);
-
+  if ($self->{YlabelPosition} and $self->{YlabelPosition} eq 'center') {
+      $img->string(font  => $font,
+		   text  => $string,
+		   x     => $xmin - ($pos_width - $neg_width) - $self->{YlabelMargin},
+		   y     => $ymax - (($ymax - $ymin)/2) - (($descent + $ascent) / 2),
+		   aa    => 1);
+  } else {
+      $img->string(font  => $font,	
+		   text  => $string,
+		   x     => $xmin-10,    # XXX: Fudge factor
+		   y     => $ymin-3,     # more fudge
+		   aa    => 1);
+  }
 
   $string = $self->{Title};
   $font   = $self->{TitleFont};
@@ -249,11 +241,10 @@ sub RenderLabels {
   $img->string(font  => $font,
 	       text  => $string,
 	       x     => ($xmin+$xmax)/2-($neg_width+$pos_width)/2,
-	       y     => $ymin-$self->{'YlabelFont'}->{'size'},
+	       y     => $ymin-$self->{'YlabelFont'}->{'size'} - $self->{YlabelMargin},
 	       aa    => 1);
 
 
-
 }
 
 
@@ -321,7 +312,7 @@ The plot is generated in a few phases.  First the initial
 plot object is generated and contains defaults at that
 point.  Then datasets are added with specifications.
 
-Look at the test for more hints on making this work.
+Look at test.pl for more hints on making this work.
 
 =head1 AUTHOR
 
@@ -332,39 +323,3 @@ Imager, perl(1).
 
 =cut
 
-
-
-
-
-
-
-
-
-
-##########################################
-#             Overall title              #
-#                                        #
-#     subtitle 1,1      subtitle 1,2     #
-#  #################  #################  #
-#  #               #  #               #  #
-#  #  subplot 1,1  #  # subplot 1,2   #  #
-#  #               #  #               #  #
-#  #               #  #               #  #
-#  #               #  #               #  #
-#  #               #  #               #  #
-#  #               #  #               #  #
-#  #################  #################  #
-#                                        #
-#     subtitle 1,1      subtitle 1,2     #
-#  #################  #################  #
-#  #               #  #               #  #
-#  #  subplot 2,1  #  # subplot 2,2   #  #
-#  #               #  #               #  #
-#  #               #  #               #  #
-#  #               #  #               #  #
-#  #               #  #               #  #
-#  #               #  #               #  #
-#  #################  #################  #
-#                                        #
-##########################################
-
